@@ -2,8 +2,8 @@
 # pylint: disable=W0611
 from .tables  import Table
 from .columns import (BooleanColumn, Column, CheckBoxColumn, DateColumn,
-                      DateTimeColumn, LinkColumn, TemplateColumn, EmailColumn,
-                      URLColumn)
+                      DateTimeColumn, EmailColumn, FileColumn, LinkColumn,
+                      TemplateColumn, URLColumn, TimeColumn)
 from .config  import RequestConfig
 from .utils   import A, Attrs
 try:
@@ -12,4 +12,4 @@ except ImportError:
     pass
 
 
-__version__ = "0.12.1"
+__version__ = "0.14.0"
