@@ -1,16 +1,18 @@
 # coding: utf-8
+from __future__ import unicode_literals
+from . import columns
+from .config import RequestConfig
+from .rows import BoundRows
+from .utils import (Accessor, AttributeDict, build_request, cached_property,
+                    OrderBy, OrderByTuple, segment, Sequence)
 import copy
 from django.core.paginator       import Paginator
 from django.db.models.fields     import FieldDoesNotExist
 from django.utils.datastructures import SortedDict
 from django.template             import RequestContext
 from django.template.loader      import get_template
-from django.utils.encoding       import StrAndUnicode
+import six
 import warnings
-from .utils import (Accessor, AttributeDict, cached_property, build_request,
-                    OrderBy, OrderByTuple, segment, Sequence)
-from .rows  import BoundRows
-from .      import columns
 
 
 QUERYSET_ACCESSOR_SEPARATOR = '__'
@@ -21,8 +23,8 @@ class TableData(object):
     Exposes a consistent API for :term:`table data`.
 
     :param  data: iterable containing data for each row
-    :type   data: :class:`QuerySet` or :class:`list` of :class:`dict`
-    :param table: :class:`.Table` object
+    :type   data: `~django.db.query.QuerySet` or `list` of `dict`
+    :param table: `.Table` object
     """
     def __init__(self, data, table):
         self.table = table
@@ -69,7 +71,7 @@ class TableData(object):
             for bound_column in self.table.columns:
                 aliases[bound_column.order_by_alias] = bound_column.order_by
             try:
-                return segment(self.queryset.query.order_by, aliases).next()
+                return next(segment(self.queryset.query.order_by, aliases))
             except StopIteration:
                 pass
 
@@ -81,7 +83,7 @@ class TableData(object):
         :param aliases: optionally prefixed names of columns ('-' indicates
                         descending order) in order of significance with
                         regard to data ordering.
-        :type  aliases: :class:`~.utils.OrderByTuple`
+        :type  aliases: `~.utils.OrderByTuple`
         """
         accessors = []
         for alias in aliases:
@@ -97,7 +99,7 @@ class TableData(object):
             translate = lambda accessor: accessor.replace(Accessor.SEPARATOR, QUERYSET_ACCESSOR_SEPARATOR)
             self.queryset = self.queryset.order_by(*(translate(a) for a in accessors))
         else:
-            self.list.sort(cmp=OrderByTuple(accessors).cmp)
+            self.list.sort(key=OrderByTuple(accessors).key)
 
     def __iter__(self):
         """
@@ -109,7 +111,7 @@ class TableData(object):
 
     def __getitem__(self, key):
         """
-        Slicing returns a new :class:`.TableData` instance, indexing returns a
+        Slicing returns a new `.TableData` instance, indexing returns a
         single record.
         """
         return self.data[key]
@@ -119,9 +121,9 @@ class TableData(object):
         """
         The full (singular) name for the data.
 
-        Queryset data has its model's ``Meta.verbose_name`` honored. List data
-        is checked for a ``verbose_name`` attribute, and falls back to using
-        ``"item"``.
+        Queryset data has its model's `~django.db.Model.Meta.verbose_name`
+        honored. List data is checked for a ``verbose_name`` attribute, and
+        falls back to using ``"item"``.
         """
         if hasattr(self, "queryset"):
             return self.queryset.model._meta.verbose_name
@@ -132,7 +134,7 @@ class TableData(object):
         """
         The full (plural) name of the data.
 
-        This uses the same approach as ``verbose_name``.
+        This uses the same approach as `.verbose_name`.
         """
         if hasattr(self, "queryset"):
             return self.queryset.model._meta.verbose_name_plural
@@ -141,16 +143,21 @@ class TableData(object):
 
 class DeclarativeColumnsMetaclass(type):
     """
-    Metaclass that converts Column attributes on the class to a dictionary
-    called ``base_columns``, taking into account parent class ``base_columns``
-    as well.
+    Metaclass that converts `.Column` objects defined on a class to the
+    dictionary `.Table.base_columns`, taking into account parent class
+    ``base_columns`` as well.
     """
-    def __new__(cls, name, bases, attrs):
-
+    def __new__(mcs, name, bases, attrs):
         attrs["_meta"] = opts = TableOptions(attrs.get("Meta", None))
         # extract declared columns
-        cols = [(name_, attrs.pop(name_)) for name_, column in attrs.items()
-                                          if isinstance(column, columns.Column)]
+        cols, remainder = [], {}
+        for attr_name, attr in attrs.items():
+            if isinstance(attr, columns.Column):
+                cols.append((attr_name, attr))
+            else:
+                remainder[attr_name] = attr
+        attrs = remainder
+
         cols.sort(key=lambda x: x[1].creation_counter)
 
         # If this class is subclassing other tables, add their fields as
@@ -159,7 +166,7 @@ class DeclarativeColumnsMetaclass(type):
         parent_columns = []
         for base in bases[::-1]:
             if hasattr(base, "base_columns"):
-                parent_columns = base.base_columns.items() + parent_columns
+                parent_columns = list(base.base_columns.items()) + parent_columns
         # Start with the parent columns
         attrs["base_columns"] = SortedDict(parent_columns)
         # Possibly add some generated columns based on a model
@@ -176,6 +183,7 @@ class DeclarativeColumnsMetaclass(type):
                         extra[name] = columns.Column()
                     else:
                         extra[name] = columns.library.column_for_field(field)
+
             else:
                 for field in opts.model._meta.fields:
                     extra[field.name] = columns.library.column_for_field(field)
@@ -193,27 +201,41 @@ class DeclarativeColumnsMetaclass(type):
             # Table's sequence defaults to sequence declared in Meta
             #attrs['_sequence'] = opts.sequence
             attrs["base_columns"] = SortedDict(((x, attrs["base_columns"][x]) for x in opts.sequence))
-        return super(DeclarativeColumnsMetaclass, cls).__new__(cls, name, bases, attrs)
+
+        # set localize on columns
+        for col_name in attrs["base_columns"].keys():
+            localize_column = None
+            if col_name in opts.localize:
+                localize_column = True
+            # unlocalize gets higher precedence
+            if col_name in opts.unlocalize:
+                localize_column = False
+
+            if localize_column is not None:
+                attrs["base_columns"][col_name].localize = localize_column
+
+        return super(DeclarativeColumnsMetaclass, mcs).__new__(mcs, name, bases, attrs)
 
 
 class TableOptions(object):
     """
-    Extracts and exposes options for a :class:`.Table` from a ``class Meta``
-    when the table is defined. See ``Table`` for documentation on the impact of
+    Extracts and exposes options for a `.Table` from a `.Table.Meta`
+    when the table is defined. See `.Table` for documentation on the impact of
     variables in this class.
 
     :param options: options for a table
-    :type  options: :class:`Meta` on a :class:`.Table`
+    :type  options: `.Table.Meta` on a `.Table`
     """
+    # pylint: disable=R0902
     def __init__(self, options=None):
         super(TableOptions, self).__init__()
         self.attrs = AttributeDict(getattr(options, "attrs", {}))
-        self.default = getattr(options, "default", u"—")
+        self.default = getattr(options, "default", "—")
         self.empty_text = getattr(options, "empty_text", None)
         self.fields = getattr(options, "fields", ())
         self.exclude = getattr(options, "exclude", ())
         order_by = getattr(options, "order_by", None)
-        if isinstance(order_by, basestring):
+        if isinstance(order_by, six.string_types):
             order_by = (order_by, )
         self.order_by = OrderByTuple(order_by) if order_by is not None else None
         self.order_by_field = getattr(options, "order_by_field", "sort")
@@ -228,75 +250,139 @@ class TableOptions(object):
         self.orderable = self.sortable = getattr(options, "orderable", getattr(options, "sortable", True))
         self.model = getattr(options, "model", None)
         self.template = getattr(options, "template", "django_tables2/table.html")
+        self.localize = getattr(options, "localize", ())
+        self.unlocalize = getattr(options, "unlocalize", ())
 
 
-class Table(StrAndUnicode):
+class TableBase(object):
     """
-    A collection of columns, plus their associated data rows.
+    A representation of a table.
 
-    :type  attrs: dict
-    :param attrs: A mapping of attributes to values that will be added to the
-            HTML ``<table>`` tag.
 
-    :type  data:  list or QuerySet-like
-    :param data: The :term:`table data`.
+    .. attribute:: attrs
 
-    :type  exclude: iterable
-    :param exclude: A list of columns to be excluded from this table.
+        HTML attributes to add to the ``<table>`` tag.
 
-    :type  order_by: None, tuple or string
-    :param order_by: sort the table based on these columns prior to display.
-            (default :attr:`.Table.Meta.order_by`)
+        :type: `dict`
 
-    :type  order_by_field: string or None
-    :param order_by_field: The name of the querystring field used to control
-            the table ordering.
+        When accessing the attribute, the value is always returned as an
+        `.AttributeDict` to allow easily conversion to HTML.
 
-    :type  page_field: string or None
-    :param page_field: The name of the querystring field used to control which
-            page of the table is displayed (used when a table is paginated).
 
-    :type  per_page_field: string or None
-    :param per_page_field: The name of the querystring field used to control
-            how many records are displayed on each page of the table.
+    .. attribute:: columns
 
-    :type  prefix: string
-    :param prefix: A prefix used on querystring arguments to allow multiple
-            tables to be used on a single page, without having conflicts
-            between querystring arguments. Depending on how the table is
-            rendered, will determine how the prefix is used. For example ``{%
-            render_table %}`` uses ``<prefix>-<argument>``.
+        The columns in the table.
 
-    :type  sequence: iterable
-    :param sequence: The sequence/order of columns the columns (from left to
-            right). Items in the sequence must be column names, or the
-            *remaining items* symbol marker ``"..."`` (string containing three
-            periods). If this marker is used, not all columns need to be
-            defined.
+        :type: `.BoundColumns`
 
-    :type  orderable: bool
-    :param orderable: Enable/disable column ordering on this table
 
-    :type  template: string
-    :param template: the template to render when using {% render_table %}
-            (default ``django_tables2/table.html``)
+    .. attribute:: default
 
-    :type  empty_text: string
-    :param empty_text: Empty text to render when the table has no data.
-            (default :attr:`.Table.Meta.empty_text`)
+        Text to render in empty cells (determined by `.Column.empty_values`,
+        default `.Table.Meta.default`)
+
+        :type: `unicode`
+
+
+    .. attribute:: empty_text
+
+        Empty text to render when the table has no data. (default
+        `.Table.Meta.empty_text`)
+
+        :type: `unicode`
+
+
+    .. attribute:: exclude
+
+        The names of columns that shouldn't be included in the table.
+
+        :type: iterable of `unicode`
+
+
+    .. attribute:: order_by_field
+
+        If not `None`, defines the name of the *order by* querystring field.
+
+        :type: `unicode`
+
+
+    .. attribute:: page
+
+        The current page in the context of pagination.
+
+        Added during the call to `.Table.paginate`.
+
+
+    .. attribute:: page_field
+
+        If not `None`, defines the name of the *current page* querystring
+        field.
+
+        :type: `unicode`
+
+
+    .. attribute:: paginator
+
+        The current paginator for the table.
+
+        Added during the call to `.Table.paginate`.
+
+
+    .. attribute:: per_page_field
+
+        If not `None`, defines the name of the *per page* querystring field.
+
+        :type: `unicode`
+
+
+    .. attribute:: prefix
+
+        A prefix for querystring fields to avoid name-clashes when using
+        multiple tables on a single page.
+
+        :type: `unicode`
+
+
+    .. attribute:: rows
+
+        The rows of the table (ignoring pagination).
+
+        :type: `.BoundRows`
+
+
+    .. attribute:: sequence
+
+        The sequence/order of columns the columns (from left to right).
+
+        :type: iterable
+
+        Items in the sequence must be :term:`column names <column name>`, or
+        ``"..."`` (string containing three periods). ``...`` can be used as a
+        catch-all for columns that aren't specified.
+
+
+    .. attribute:: orderable
+
+        Enable/disable column ordering on this table
+
+        :type: `bool`
+
+
+    .. attribute:: template
+
+        The template to render when using ``{% render_table %}`` (default
+        ``"django_tables2/table.html"``)
+
+        :type: `unicode`
 
-    :type  default: unicode
-    :param default: Text to render in empty cells (determined by
-            :attr:`Column.empty_values`, default :attr:`.Table.Meta.default`)
     """
-    __metaclass__ = DeclarativeColumnsMetaclass
     TableDataClass = TableData
 
     def __init__(self, data, order_by=None, orderable=None, empty_text=None,
                  exclude=None, attrs=None, sequence=None, prefix=None,
                  order_by_field=None, page_field=None, per_page_field=None,
-                 template=None, sortable=None, default=None):
-        super(Table, self).__init__()
+                 template=None, sortable=None, default=None, request=None):
+        super(TableBase, self).__init__()
         self.exclude = exclude or ()
         self.sequence = sequence
         self.data = self.TableDataClass(data=data, table=self)
@@ -350,9 +436,9 @@ class Table(StrAndUnicode):
         else:
             self.order_by = order_by
         self.template = template
-
-    def __unicode__(self):
-        return unicode(repr(self))
+        # If a request is passed, configure for request
+        if request:
+            RequestConfig(request).configure(self)
 
     def as_html(self):
         """
@@ -368,12 +454,6 @@ class Table(StrAndUnicode):
 
     @property
     def attrs(self):
-        """
-        The attributes that should be applied to the ``<table>`` tag when
-        rendering HTML.
-
-        :rtype: :class:`~.utils.AttributeDict` object.
-        """
         return self._attrs if self._attrs is not None else self._meta.attrs
 
     @attrs.setter
@@ -403,7 +483,7 @@ class Table(StrAndUnicode):
         # collapse empty values to ()
         order_by = () if not value else value
         # accept string
-        order_by = order_by.split(',') if isinstance(order_by, basestring) else order_by
+        order_by = order_by.split(',') if isinstance(order_by, six.string_types) else order_by
         valid = []
         # everything's been converted to a iterable, accept iterable!
         for alias in order_by:
@@ -436,17 +516,18 @@ class Table(StrAndUnicode):
         Paginates the table using a paginator and creates a ``page`` property
         containing information for the current page.
 
-        :type     klass: Paginator ``class``
+        :type     klass: Paginator class
         :param    klass: a paginator class to paginate the results
-        :type  per_page: ``int``
+        :type  per_page: `int`
         :param per_page: how many records are displayed on each page
-        :type      page: ``int``
+        :type      page: `int`
         :param     page: which page should be displayed.
 
-        Extra arguments are passed to ``Paginator``.
+        Extra arguments are passed to the paginator.
 
-        Pagination exceptions (``EmptyPage`` and ``PageNotAnInteger``) may be
-        raised from this method and should be handled by the caller.
+        Pagination exceptions (`~django.core.paginator.EmptyPage` and
+        `~django.core.paginator.PageNotAnInteger`) may be raised from this
+        method and should be handled by the caller.
         """
         per_page = per_page or self._meta.per_page
         self.paginator = klass(self.rows, per_page, *args, **kwargs)
@@ -472,15 +553,15 @@ class Table(StrAndUnicode):
 
     @property
     def prefixed_order_by_field(self):
-        return u"%s%s" % (self.prefix, self.order_by_field)
+        return "%s%s" % (self.prefix, self.order_by_field)
 
     @property
     def prefixed_page_field(self):
-        return u"%s%s" % (self.prefix, self.page_field)
+        return "%s%s" % (self.prefix, self.page_field)
 
     @property
     def prefixed_per_page_field(self):
-        return u"%s%s" % (self.prefix, self.per_page_field)
+        return "%s%s" % (self.prefix, self.per_page_field)
 
     @property
     def sequence(self):
@@ -522,3 +603,6 @@ class Table(StrAndUnicode):
     @template.setter
     def template(self, value):
         self._template = value
+
+# Python 2/3 compatible way to enable the metaclass
+Table = DeclarativeColumnsMetaclass(str('Table'), (TableBase, ), {})
